* THIS DO-FILE CREATED THE CEM PANEL

************************************************************************************************************************
***											1. LOAD AND PREPARE PANEL DATA											 ***
************************************************************************************************************************

*Load monthly panel data
use $dataset.dta, clear
xtset name_id t


*** PREPARE VARIABLES
*Treated variable for mentioned pilots
gen treated = 0
replace treated = 1 if vic_mentions_new != 0

*Lagged victories
gen l1vic=l1.vic
gen l2vic=l2.vic
gen l3vic=l3.vic 

*Number of mentions per month
bysort t: egen num_mentions_period = sum(anymention)
replace num_mentions_period = num_mentions_period - 1 if anymention == 1
replace num_mentions_period = 1 if num_mentions_period > 1



************************************************************************************************************************
***												2. APPLY CEM ALGORITHM												 ***
************************************************************************************************************************

***Match on coarsened 3 month vics, and coarsened pilot_quality, month and front

*Define quality splits based on percentiles
_pctile pilot_quality_scwadj, nq(5)
return list		//use these values for coarsening quality

*Drop ever-mentioned pilots in non-mention periods
bysort name_id: egen ever_mentioned_n = max(treated)
drop if ever_mentioned_n == 1 & vic_mentions_new == 0


*** a. CEM match
cem front(#0) num_mentions_period(#0) pilot_quality_scwadj(.0535714 .1818182 .4 .8181818)	///
	vic(#5) l1vic(#5) l2vic(#5) l3vic(#5) 													///
	, treatment(treated) showbreaks autocuts(fd)
	
count if treated == 1 & cem_matched == 1 


*** b. only keep matches with highest pscores in each strata to get k-to-5k matches
keep if cem_matched == 1

*get the number of treated observations in each strata
sort cem_strata, stable
by cem_strata: egen num_treated = total(treated)

*get a list of strata with treated observations
levelsof cem_strata, local(strata_num)

*calculate pscore
pscore treated vic l1vic l2vic l3vic pilot_quality_scwadj front num_mentions_period, pscore(pscore) 

*keep the control observations with the highest 5* n pscores where n = number of treated in strata
sort cem_strata treated pscore, stable
bysort cem_strata treated: gen rank = _N - _n + 1

drop if rank > num_treated * 5


************************************************************************************************************************
***												TABLE 2: BALANCEDNESS												 ***
************************************************************************************************************************
preserve		
	iebaltab vic l1vic l2vic l3vic pilot_quality_scwadj front cvic_scwadj num_mentions_period, ///
			grpvar(treated)    ///
			savetex("$gphpath/table2_temp1.tex") replace browse ///
			tblnonote rowvarlabels grplabels(0 Placebo @ 1 Mention)	///
			rowlabels(vic "Victories in (placebo) mention period (\(t=0\))" @	///
					  l1vic "Victories in \(t=-1\)" @	///
					  l2vic "Victories in \(t=-2\)" @	///
					  l3vic "Victories in \(t=-3\)" @	///
					  pilot_quality_scwadj "Pilot quality" @	///
					  front "Eastern front" @	///
					  cvic_scwadj "Cumulative victories in \(t=0\)" @	///
					  num_mentions_period "Other pilots mentioned in \(t=0\)")	///
			texcolwidth(7cm)

	*Make table look like booktabs (booktabs option not available with iebaltab)
	filefilter "$gphpath/table2_temp1.tex" "$gphpath/table2_temp2.tex", from("\BShline \BShline") to("\BShline") replace
	filefilter "$gphpath/table2_temp2.tex" "$gphpath/table2_temp3.tex", from("\BSmulticolumn{1}{c}{T-test}") to("\BSmulticolumn{1}{c}{(3)}") replace
	filefilter "$gphpath/table2_temp3.tex" "$gphpath/table2.tex", from("\BSmulticolumn{1}{c}{Difference}") to("\BSmulticolumn{1}{c}{T-test Difference}") replace

	erase "$gphpath/table2_temp1.tex"
	erase "$gphpath/table2_temp2.tex"
	erase "$gphpath/table2_temp3.tex"
restore



************************************************************************************************************************
***								FIGURE 3: SIMILARITY OF TREATMENT AND CONTROL GROUP									 ***
************************************************************************************************************************
preserve
	*Panel A: pilot quality
	robbox pilot_quality, over(treated) xlabels(1 "Mentioned pilots" 2 "Placebo-mentioned pilots")	///
		   ytitle("Pilot quality") sort descending
	graph export "$gphpath/figure3_quality.eps", replace

	*Panel B: victories	
	robbox vic, over(treated) xlabels(1 "Mentioned pilots" 2 "Placebo-mentioned pilots")	///
		  ytitle("Victories") sort
	graph export "$gphpath/figure3_victories.eps", replace

restore


************************************************************************************************************************
***										3. ADD CEM VARIABLES TO MAIN DATASET										 ***
************************************************************************************************************************

*Keep only name, time and treated variables
keep name_id t treated 
*Create matched variable
gen matched = 1 if treated ==0
recode matched . = 0

*Add variables to main dataset
merge 1:1 name_id t using $dataset.dta
recode matched . = 0
recode treated . = 0
drop _m

*save
label variable treated 				"=1 if mentioned"
label variable matched 				"=1 if placebo-mentioned"
save ghostpilots_CEM_v1.dta, replace


************************************************************************************************************************
***										4. EXPAND TO SAMPLE WITH GHOST PILOTS										 ***
************************************************************************************************************************

*load program to add ghost pilots 
do "$path/code/helper_programs/add_ghosts.do"

*run program
add_ghosts

*save
drop t_min t_max ghost_month
save ghostpilots_CEM_v1.dta, replace



************************************************************************************************************************
***							5. FIND PAST PEERS OF MENTIONED AND PLACEBO-MENTIONED PILOTS							 ***
************************************************************************************************************************

*load program to add past peer variables
do "$path/code/helper_programs/gen_pastpeer_monthly.do"

*add pastpeerofmatched
gen_pastpeer_monthly matched ghostpilots_CEM_v1
tab pastpeerofmatched
save ghostpilots_CEM_v1.dta, replace

*add pastpeeroftreated
gen_pastpeer_monthly treated ghostpilots_CEM_v1
tab pastpeeroftreated
save ghostpilots_CEM_v1.dta, replace

*add pastpeerofanymention
gen_pastpeer_monthly anymention ghostpilots_CEM_v1
tab pastpeerofanymention
save ghostpilots_CEM_v1.dta, replace

*save
drop treatedperiod matchedperiod anymentionperiod
label variable pastpeeroftreated 	"=1 if former peer is mentioned"
label variable pastpeerofmatched 	"=1 if former peer is placebo-mentioned"
label variable pastpeerofanymention	"=1 if former peer is mentioned or placebo-mentioned"
save ghostpilots_CEM_v1.dta, replace


	********************************************************************************************************************
	***											ALTERNATIVE PEER DEFINITION											 ***
	********************************************************************************************************************
	save ghostpilots_CEM_groupbase.dta, replace

	***FIND PAST PEERS: GROUP PEERS
	*load program to generate pastpeer variables
	do "$path/code/helper_programs/gen_pastpeer_group_monthly.do"

	*add pastpeerofmatched
	gen_pastpeer_group_monthly matched ghostpilots_CEM_groupbase
	tab pastgrouppeer_only_ofmatched
	save ghostpilots_CEM_groupbase.dta, replace

	*add pastpeeroftreated
	gen_pastpeer_group_monthly treated ghostpilots_CEM_groupbase
	tab pastgrouppeer_only_oftreated
	save ghostpilots_CEM_groupbase.dta, replace


	***FIND PAST PEERS: BASE PEERS
	*load program to generate pastpeer variables
	do "$path/code/helper_programs/gen_pastpeer_base_monthly.do"

	*add pastpeerofmatched
	gen_pastpeer_base_monthly matched ghostpilots_CEM_groupbase
	tab pastbasepeer_only_ofmatched
	save ghostpilots_CEM_groupbase.dta, replace

	*add pastpeeroftreated
	gen_pastpeer_base_monthly treated ghostpilots_CEM_groupbase
	tab pastbasepeer_only_oftreated
	save ghostpilots_CEM_groupbase.dta, replace


	*** CREATE DATASETS
	*load program to generate pastpeer variables
	do "$path/code/helper_programs/gen_windows.do"
	
	**SQUADRON PEERS
	use ghostpilots_CEM_groupbase.dta, clear

	*run program to line up pilots in event time
	gen_windows pastpeeroftreated pastpeerofmatched ghostpilots_CEM_groupbase $dataset

	*merge in pastpeer variable
	merge m:1 name_id t using ghostpilots_CEM_groupbase, keepusing(pastpeerofanymention)
	keep if _m == 3
	drop _m

	*non-negative event time variable
	su event_time
	local min = `r(min)'
	gen et = event_time - `min' + 1

	*limit to those that are past peers at some point
	gegen pastpeer_pilot = max(pastpeerofanymention),  by(name_id)
	keep if pastpeer_pilot == 1

	*drop all the events of control that have pastpeerofanymention treatment in t0
	gen treat_in_t0 = 0
	replace treat_in_t0 = 1 if event_time == 0 ///
								 & pastpeerofanymention == 1 ///
								 & treated == 0					 
	bysort event_num treated: egen treated_control = max(treat_in_t0)
	drop if treated_control == 1

	* prepare unique event id
	egen event_id = group(event_num treated)

	*save data for later regressions
	keeporder name_id et vic post_x_treatment treated id_squadron exp_scw event_id exit
	label variable et				"event time"
	label variable post_x_treatment	"= 1 if post treatment"
	save eventpilots_sqpeers.dta, replace


	**GROUP PEERS
	use ghostpilots_CEM_groupbase, clear

	*run program to line up pilots in event time
	gen_windows pastgrouppeer_only_oftreated pastgrouppeer_only_ofmatched ghostpilots_CEM_groupbase $dataset

	*merge in pastpeer variable
	merge m:1 name_id t using ghostpilots_CEM_groupbase, keepusing(pastpeerofanymention)
	keep if _m == 3
	drop _m

	*non-negative event time variable
	su event_time
	local min = `r(min)'
	gen et = event_time - `min' + 1

	*limit to those that are past peers at some point
	gegen pastpeer_pilot = max(pastpeerofanymention),  by(name_id)
	keep if pastpeer_pilot == 1

	*drop all the events of control that have pastpeerofanymention treatment in t0
	gen treat_in_t0 = 0
	replace treat_in_t0 = 1 if event_time == 0 ///
								 & pastpeerofanymention == 1 ///
								 & treated == 0							 
	bysort event_num treated: egen treated_control = max(treat_in_t0)
	drop if treated_control == 1

	* prepare unique event id
	egen event_id = group(event_num treated)

	*save data for later regressions
	keeporder name_id et vic post_x_treatment treated id_squadron exp_scw event_id exit
	label variable et				"event time"
	label variable post_x_treatment	"= 1 if post treatment"
	save eventpilots_grpeers.dta, replace


	**BASE PEERS
	use ghostpilots_CEM_groupbase, clear

	*run program to line up pilots in event time
	gen_windows pastbasepeer_only_oftreated pastbasepeer_only_ofmatched ghostpilots_CEM_groupbase $dataset

	*merge in pastpeer variable
	merge m:1 name_id t using ghostpilots_CEM_groupbase, keepusing(pastpeerofanymention)
	keep if _m == 3
	drop _m

	*non-negative event time variable
	su event_time
	local min = `r(min)'
	gen et = event_time - `min' + 1

	*limit to those that are past peers at some point
	gegen pastpeer_pilot = max(pastpeerofanymention),  by(name_id)
	keep if pastpeer_pilot == 1

	*drop all the events of control that have pastpeerofanymention treatment in t0
	gen treat_in_t0 = 0
	replace treat_in_t0 = 1 if event_time == 0 ///
								 & pastpeerofanymention == 1 ///
								 & treated == 0
								 
	bysort event_num treated: egen treated_control = max(treat_in_t0)
	drop if treated_control == 1

	*prepare unique event id
	egen event_id = group(event_num treated)

	*save data for later regressions
	keeporder name_id et vic post_x_treatment treated id_squadron exp_scw event_id exit
	label variable et				"event time"
	label variable post_x_treatment	"= 1 if post treatment"
	save eventpilots_bapeers.dta, replace

	*Erase
	erase ghostpilots_CEM_groupbase.dta

	
	
************************************************************************************************************************
***											7. ADD BIRTH PLACE DISTANCE												 ***
************************************************************************************************************************
use ghostpilots_CEM_v1.dta, clear

***FILL UP LATITUDE AND LONGITUDE FOR GHOST MONTHS
sort name_id t 
forvalues i = 1/3 {
	*longitude
	by name_id: egen birth_longitude`i'_g = max(birth_longitude`i')
	drop birth_longitude`i'
	rename birth_longitude`i'_g birth_longitude`i'
	*latitude
	by name_id: egen birth_latitude`i'_g = max(birth_latitude`i')
	drop birth_latitude`i'
	rename birth_latitude`i'_g birth_latitude`i'
	
}

***COMBINE INFOS FROM ALL SOURCES (IF CONFLICTING INFO: TAKE HAND COLLECTED DATA FROM SOURCE 1)
*longitude
gen birth_longitude = birth_longitude1
replace birth_longitude = birth_longitude2 if birth_longitude1 ==.
replace birth_longitude = birth_longitude3 if birth_longitude1 ==. & birth_longitude2 ==.

*latitude
gen birth_latitude = birth_latitude1
replace birth_latitude = birth_latitude2 if birth_latitude1 ==.
replace birth_latitude = birth_latitude3 if birth_latitude1 ==. & birth_latitude2 ==.


***GET LONGITUDE AND LATITUDE OF EACH MENTIONED PILOT
gen ever_mentioned_id = name_id if anymention == 1
levelsof ever_mentioned_id, local(peerlist)
foreach i of local peerlist {
	*longitude
	gen longitude_`i'_h = birth_longitude if name_id == `i'
	egen longitude_`i' = max(longitude_`i'_h)
	*latitude
	gen latitude_`i'_h = birth_latitude if name_id == `i'
	egen latitude_`i' = max(latitude_`i'_h)
}

save ghostpilots_CEM_v1, replace


*** COMPUTE MEAN DISTANCE TO MENTIONED PEERS
*compute the distance to all peers with birth location available
gen ever_mentioned_withloc_id = ever_mentioned_id
replace ever_mentioned_withloc_id = . if birth_longitude ==. | birth_latitude ==.

levelsof ever_mentioned_withloc_id, local(peerlist)
foreach i of local peerlist {
	vincenty birth_latitude birth_longitude latitude_`i' longitude_`i', vin(distance_`i')
}

*only keep distances if pilot is mentioned
levelsof ever_mentioned_withloc_id, local(peerlist)
foreach i of local peerlist {
	gen mentioned_`i'_h = 0
	replace mentioned_`i'_h = 1 if anymention == 1 & name_id == `i'
	
	bysort t: egen mentioned_`i' = max(mentioned_`i'_h)
	
	gen distance_`i'_mentioned = distance_`i' if mentioned_`i' == 1
}

*get the mean distance to all the pilots that are mentioned
order distance_*_mentioned, last
egen birthdistance = rowmean(distance_115_mentioned-distance_4845_mentioned)

*drop mentioned, latitude, longitude and distance variables
drop mentioned_* distance_* latitude_* longitude_*

*save
save ghostpilots_CEM_v1, replace


************************************************************************************************************************
***												6. ADD BASE DISTANCE												 ***
************************************************************************************************************************
use ghostpilots_CEM_v1, replace

*** FIND NAME_ID OF MENTIONED PAST PEER
*get list of ever mentioned pilots
cap gen ever_mentioned_id = name_id if anymention == 1
save ghostpilots_CEM_v1, replace

*load program to generate pastpeer variables
do "$path/code/helper_programs/gen_pastpeer_monthly.do"
*search past peers for each mentioned pilot separately
levelsof ever_mentioned_id, local(peerlist)
foreach i of local peerlist {
	
	*define pilot
	gen pilot`i' = 0
	replace pilot`i' = 1 if anymention == 1 & name_id == `i'
	
	*run program to find past peers of that pilot
	save ghostpilots_CEM_v1, replace
	gen_pastpeer_monthly  pilot`i' ghostpilots_CEM_v1
	tab pastpeerofpilot`i'		
}

*save intermediate version of data
save ghostpilots_CEM_v1.dta, replace	

*** GET LATITUDE AND LONGITUDE OF MENTIONED PAST PEERS
levelsof ever_mentioned_id, local(peerlist)
foreach i of local peerlist {
	*longitude
	gen longitude_`i'_h = base_longitude if name_id == `i'
	bysort t: egen longitude_`i' = max(longitude_`i'_h)
	*latitude
	gen latitude_`i'_h = base_latitude if name_id == `i'
	bysort t: egen latitude_`i' = max(latitude_`i'_h)
}

*save
save ghostpilots_CEM_v1, replace


*** IDENTIFY MENTIONED PAST PEER IN t-6
xtset name_id t
levelsof ever_mentioned_id, local(peerlist)
foreach i of local peerlist {	
	gen pastpeerofpilot`i'_t6 = 0
	replace pastpeerofpilot`i'_t6 = 1 if pastpeerofpilot`i'[_n+6] == 1 & name_id == name_id[_n+6]
}

*Drop
foreach var of varlist pastpeerofpilot*_t6{
	local var_new = "keep_" + "`var'"
	rename `var' `var_new'
} 
drop pastpeerofpilot*
foreach var of varlist keep_pastpeerofpilot*_t6{
	local var_new = subinstr("`var'", "keep_", "", .)
	rename `var' `var_new'
} 

drop pilot*

*save
save ghostpilots_CEM_v1, replace




************************************************************************************************************************
***											7. ADD MENTIONED-PILOT-CLUSTER											 ***
************************************************************************************************************************

use ghostpilots_CEM_v1.dta, clear

*create separate mention variables for actually mentioned pilots
do "$path/code/helper_programs/gen_pastpeer_monthly.do"

levelsof name_id if treated == 1, local(treat_id)
foreach i of local treat_id {
	gen     treated_`i' = 0
	replace treated_`i' = 1 if treated == 1 & name_id == `i'
	*run program
	save ghostpilots_temp_cluster.dta, replace
	gen_pastpeer_monthly treated_`i' ghostpilots_temp_cluster
}
save ghostpilots_temp_cluster.dta, replace


*create separate mention variables for placebo mentioned pilots
do "$path/code/helper_programs/gen_pastpeer_monthly.do"

levelsof name_id if matched == 1   & /// there are no past peers for the following ids
					name_id != 526 & name_id != 957, local(match_id) 
foreach i of local match_id {
	gen     matched_`i' = 0
	replace matched_`i' = 1 if matched == 1 & name_id == `i'
	*run program
	save ghostpilots_temp_cluster2.dta, replace
	gen_pastpeer_monthly matched_`i' ghostpilots_temp_cluster2		
}

save ghostpilots_temp_cluster2.dta, replace




************************************************************************************************************************
***											8. LINE UP PILOTS IN EVENT TIME											 ***
************************************************************************************************************************

*load program to line up pilots in event time
do "$path/code/helper_programs/gen_windows_cluster.do"

*run program
gen_windows pastpeeroftreated pastpeerofmatched ghostpilots_temp_cluster2 $dataset

*merge in pastpeer variable based on daily-to-monthly squadron structure
merge m:1 name_id t using ghostpilots_temp_cluster2, keepusing(pastpeerofanymention birthdistance  base_longitude longitude_* base_latitude latitude_* pastpeerofpilot*)
keep if _m == 3
drop _m



************************************************************************************************************************
***												9. PREPARE VARIABLES												 ***
************************************************************************************************************************
*non-negative event time variable
su event_time
local min = `r(min)'
gen et = event_time - `min' + 1
su et

*variable for ever past peer
gegen pastpeer_pilot = max(pastpeerofanymention),  by(name_id)
tab pastpeer_pilot
keep if pastpeer_pilot == 1

* create event ids
egen event_id = group(event_num treated)

*create id variable for clustered SEs by mentioned pilot
forvalues i = 1/5 {
	recode event_peer_id`i' . = 0
}
egen peer_cluster = group(event_peer_id1-event_peer_id5)
su peer_cluster // there are 277 different clusters

*drop event_peer_id variables
drop event_peer_id*

***Alternative outcomes
*ratio of exits over vicdays_per_month
gen exit_vicdays_ratio = exit / vicdays_per_month

*ratio of exits over victories
gen exit_vic_ratio = exit / vic


***Birthplace distance
*get birthdistance at t0 for the entire event-window
gen birthdistance_t0 = birthdistance if event_time == 0
bysort event_id: egen birthdistance_window = max(birthdistance_t0)


***Base distance
*compute the distance to all peers
preserve 
	use $dataset, clear
	cap gen ever_mentioned_id = name_id if anymention == 1
	levelsof ever_mentioned_id, local(peerlist)
restore
foreach i of local peerlist {
	vincenty base_latitude base_longitude latitude_`i' longitude_`i', vin(distance_`i')
}

*get the number of peers
gen peer_num = 0
preserve 
	use $dataset, clear
	cap gen ever_mentioned_id = name_id if anymention == 1
	levelsof ever_mentioned_id, local(peerlist)
restore
foreach i of local peerlist {
	replace peer_num = peer_num + 1 if pastpeerofpilot`i'_t6 == 1
}
su peer_num // maximally 2 peers


*get name_ids of all peers 
gen peer_id1 = .
gen peer_id2 = .

preserve 
	use $dataset, clear
	cap gen ever_mentioned_id = name_id if anymention == 1
	levelsof ever_mentioned_id, local(peerlist)

restore
foreach i of local peerlist {
	replace peer_id1 = `i' if pastpeerofpilot`i'_t6 == 1 & peer_id1 == .
}

foreach i of local peerlist {
	replace peer_id2 = `i' if pastpeerofpilot`i'_t6 == 1 & peer_id2 == . ///
						   &  peer_id1 != .           & peer_id1 < `i'
}


*get the min distance to all peers
gen distancementioned = .

*Case 1: there is only one mentioned peer 
preserve 
	use $dataset, clear
	cap gen ever_mentioned_id = name_id if anymention == 1
	levelsof ever_mentioned_id, local(peerlist)
restore

foreach i of local peerlist {
	replace distancementioned = distance_`i' if peer_id1 == `i'
}

*Case 2: there are two mentioned peers
foreach i of local peerlist {
	replace distancementioned = distance_`i' if peer_id2 == `i' & distance_`i' < distancementioned
}


*aggregate distance variable up to the level of the event-window
gen distancementioned_h = distancementioned if event_time == -6
bysort event_id: egen distancementioned_window = max(distancementioned_h)

*drop pastpeerofpilot, latitude, longitude, distance, peer_id variables
drop pastpeerofpilot* latitude_* longitude_* distance_* peer_id*


************************************************************************************************************************
***							10. DROP EVENTS OF CONTROL THAT HAVE PASTPEEROFANYMENTION IN t0							 ***
************************************************************************************************************************

gen treat_in_t0 = 0
replace treat_in_t0 = 1 if event_time == 0 ///
							 & pastpeerofanymention == 1 ///
							 & treated == 0
							 
br treated event_num event_time name_id t et pastpeerofanymention treat_in_t0
bysort event_num treated: egen treated_control = max(treat_in_t0)
tab treated_control
	
drop if treated_control == 1




************************************************************************************************************************
***											10. ADD QUALITY PERCENTILES												 ***
************************************************************************************************************************

***CREATE VARIABLE FOR QUALITY IN t-6
*identify pilot quality in t-6
gen quality_t6_h = 0
replace quality_t6_h = pilot_quality_scwadj if event_time == -6
bysort event_id: egen quality_t6 = max(quality_t6_h)

*only keep events where pilots are still alive in t-6
gen exist6_h = 0
replace exist6_h = 1 if event_time == -6
bysort event_num treated: egen exist_start = max(exist6_h)
//drop if exist_start == 0


***QUALITY SPLIT: 80-20
*find 80th percentile quality in t-6
preserve 
	keep if event_time == -6
	egen perc80 = pctile(quality_t6),p(80)
	local p80 = perc80 in 1
restore

*create identifier for top20 quality in t-6
gen top20 = 0
replace top20 = 1 if quality_t6 >= `p80'


***QUALITY SPLIT: 90-10
*find 90th percentile quality in t-6
preserve 
	keep if event_time == -6
	egen perc90 = pctile(quality_t6),p(90)
	local p90 = perc90 in 1
	display "`p90'"
restore

*create identifier for top10 quality in t-6
gen top10 = 0
replace top10 = 1 if quality_t6 >= `p90'


***QUALITY SPLIT: 70-30
*find 70th percentile quality in t-6
preserve 
	keep if event_time == -6
	egen perc70 = pctile(quality_t6),p(70)
	local p70 = perc70 in 1
	display "`p70'"
restore

*create identifier for top30 quality in t-6
gen top30 = 0
replace top30 = 1 if quality_t6 >= `p70'



************************************************************************************************************************
***									11. SAVE FINAL DATASET AND DELETE TEMPORARY DATASETS							 ***
************************************************************************************************************************

*Drop
drop pastpeer_pilot birthdistance birthdistance_t0 peer_num distancementioned distancementioned_h treat_in_t0	///
	 quality_t6_h quality_t6 exist6_h
*Label
label variable event_num				"event number"
label variable event_num				"event identifier"
label variable event_time				"event time"
label variable et						"event time"
label variable treated					"=1 if pilot is treated"
label variable post						"=1 if post treatment"
label variable post_x_treatment			"=1 if treated and post treatment"
label variable exit_vicdays_ratio 		"ratio of exit to number of days with victories in a month"
label variable exit_vic_ratio			"ratio of exit to victories"
label variable birthdistance_window		"distance between birth places of pilot and mentioned past peer"
label variable distancementioned_window	"distance between bases of pilot and mentioned past peer"
label variable treated_control			"=1 if treated and control"
label variable exist_start				"=1 if pilot exists in t-6"
label variable top10					"=1 if pilot is in the top 10 quality percentile"
label variable top20					"=1 if pilot is in the top 20 quality percentile"
label variable top30					"=1 if pilot is in the top 30 quality percentile"

*Save
compress
save pilotsmonthly_CEM.dta, replace

*erase temp data
erase ghostpilots_CEM_v1.dta
erase ghostpilots_temp_cluster.dta
erase ghostpilots_temp_cluster2.dta


