# Create social universe variables

# Import
import sys
import subprocess

# implement pip as a subprocess:
if sys.platform == "darwin":
    subprocess.check_call([sys.executable, '-m', 'pip', 'install', 'pandas==1.2.4'])
    subprocess.check_call([sys.executable, '-m', 'pip', 'install', 'numpy==1.20.2'])
elif sys.platform == "win32":
    python_exec = sys.base_prefix + "\\python.exe"
    subprocess.check_call([python_exec, '-m', 'pip', 'install', 'pandas==1.2.4'])
    subprocess.check_call([python_exec, '-m', 'pip', 'install', 'numpy==1.20.2'])
else:
    print("Installation of packages only automated for Mac OSX and Windows. Install manually if using other OS.")

import numpy as np
import pandas as pd
import os

# Input paths
pilots_pth = r"../currentdata/pilotsmonthly.dta"
peers_pth = r"../currentdata/temp/allpeers_monthly.dta"
squadron_pth = r"../currentdata/temp/squadronlist_monthly.dta"

# Temporary output paths
new_peers_pth = r"../currentdata/temp/new_peers.dta"

# Output Paths
# How many alive people has a soldier served with who have a common connection to a mentioned soldier this month
# mentioned soldier must not currently be in squadron, if 2 mentions in common then count twice
common_mention_path = r"../currentdata/socialuniverse_variables.dta"

# Load datasets
pilots_data = pd.read_stata(pilots_pth)
peers_data = pd.read_stata(peers_pth)
squadron_data = pd.read_stata(squadron_pth)

# Get the month of each death
death_months = pilots_data.loc[pilots_data['exit'] == 1][['name_id', 't']]

# Remove dead relationships
if not os.path.isfile(new_peers_pth):  # Don't process if the file exists
    for i, (_, row) in enumerate(death_months.iterrows()):
        # Keep if (id still alive) or ((id not peer_comp) and (id not name_id))
        peers_data = peers_data[(peers_data.t <= row.t) | ((peers_data.peer_comp != row.name_id) & (peers_data.name_id != row.name_id))]
        if i % 100 == 0: # For printing progress
            print("{}/{} dead soldiers removed".format(i, len(death_months)))
    peers_data.to_stata(new_peers_pth, write_index=False)
else:
    peers_data = pd.read_stata(new_peers_pth)

# Count relationship per time period
social_universes = peers_data.groupby(['name_id', 't']).count()

# Count the number of people currently in your squadron
squadron_sizes = squadron_data.groupby(['name_id', 't']).count()

# Count number of peers for each month and then cumulative sum over t (sort to insure we ascend through t)
peer_months = squadron_data.groupby([squadron_data.name_id, squadron_data.t]).count().sort_index(level=[0, 1]).groupby(level=0).cumsum()

# Rename columns
social_universes = social_universes.rename(columns={"peer_comp": "number_collected"})
peer_months = peer_months.rename(columns={"peer_comp": "peer_months"})


social_universes = social_universes.join(peer_months[["peer_months"]])


#  Fix missing peer months, this happens because we build them off squadron_data meaning that if a pilot has no squad
#  members at t then they have no entry at t so we set t's cumulative sum to the same value as t-1

for i, ((id, t), missing_entry) in enumerate(social_universes[social_universes.isna().any(axis=1)].iterrows()):
    social_universes['peer_months'][id][t] = social_universes.loc[id, t-1]['peer_months']


# Find all mentions
mentions = pilots_data.loc[pilots_data['anymention'] == 1][['name_id', 't']]

# Create common mention dataset initilized with 0 counts
# We use the entries in social_universes to insure we only have entries for alive soldiers
common_with_mention = social_universes
common_with_mention['total_common'] = 0.0

common_with_mention['common_months1'] = 0.0
common_with_mention['common_months2'] = 0.0
common_with_mention['common_months3'] = 0.0


"""
Description:
We go through all mentions (a), find their peers (b) that do not currently serve with them, and then add the number of
common peers count(c) to b's entry for the current time (t) in common_with_mention.


a: currently mentioned peer
b: all peers common with a and not currently serving with a
common_peers: all peers common between a and b

For months we add 3 measures. 1. Number of peer months shared between in common (c) and current (b)
                              2. Number of peer months shared between in common (c) and mentioned (a)
                              3. Number of peer months shared between current (b) and mentioned (a)
"""
for i, (_, mention) in enumerate(mentions.iterrows()):
    peers_a = peers_data.loc[(peers_data.name_id == mention.name_id) & (peers_data.t == mention.t)]
    peers_current_a = squadron_data.loc[(squadron_data.name_id == mention.name_id) & (squadron_data.t == mention.t)]
    peers_past_only_a = set([x for x in peers_a.peer_comp]) - set([x for x in peers_current_a.peer_comp])
    for id in peers_past_only_a:
        peers_b = peers_data.loc[(peers_data.name_id == id) & (peers_data.t == mention.t)]
        common_peers = set([x for x in peers_a.peer_comp]).intersection(set([x for x in peers_b.peer_comp]))
        common_with_mention['total_common'][id][mention.t] = common_with_mention['total_common'][id][mention.t] + len(common_peers)
        for common_peer in common_peers:
            common_with_mention['common_months1'][id][mention.t] = common_with_mention['common_months1'][id][mention.t] + \
                                                                   len(squadron_data[(squadron_data.name_id==id) & (squadron_data.peer_comp == common_peer)])
            common_with_mention['common_months2'][id][mention.t] = common_with_mention['common_months2'][id][mention.t] + \
                                                                   len(squadron_data[(squadron_data.name_id == common_peer) & (squadron_data.peer_comp == mention.name_id)])
            common_with_mention['common_months3'][id][mention.t] = common_with_mention['common_months3'][id][mention.t] + \
                                                                   len(squadron_data[(squadron_data.name_id == id) & (squadron_data.peer_comp == mention.name_id)])
    print("{}/{} mentions added".format(i, len(mentions)))


# Add dummy variable
common_with_mention['common_dummy'] = np.where(common_with_mention['total_common'] > 0, 1, 0)

# Output common with mention
common_with_mention = common_with_mention[['total_common', 'number_collected']]
common_with_mention.to_stata(common_mention_path, variable_labels={'total_common': 'total number of peers in common with someone mentioned this month',
                                                                    'number_collected': 'count alive pilots this pilot has shared a squadron with'
                                                                   })

# Remove temp file
os.remove(new_peers_pth)
